@@ -1,5 +1,5 @@
 # Import the packages
 from pympi.Praat import TextGrid
-from pympi.Elan import Eaf
+from pympi.Elan import Eaf, eaf_from_chat
 
 __all__ = ['Praat', 'Elan', 'eaf_from_chat']
